#[repr(C)]pub struct StoreExportResponse {
pub filled: Vmo,
}Expand description
The wire type corresponding to StoreExportResponse.
Fields
filled: VmoTrait Implementations
Sourceimpl Constrained for StoreExportResponse
impl Constrained for StoreExportResponse
Sourceimpl Debug for StoreExportResponse
impl Debug for StoreExportResponse
Sourceimpl<___D> Decode<___D> for StoreExportResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for StoreExportResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<StoreExportResponse, ___E> for StoreExportResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<StoreExportResponse, ___E> for StoreExportResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StoreExportResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, StoreExportResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StoreExportResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StoreExportResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StoreExportResponse, ___E> for StoreExportResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Vmo, ___E>,
impl<___E, T0> Encode<StoreExportResponse, ___E> for StoreExportResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Vmo, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StoreExportResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StoreExportResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StoreExportResponse> for StoreExportResponse
impl FromWire<StoreExportResponse> for StoreExportResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StoreExportResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<StoreExportResponse, Self>
Sourcefn from_wire(wire: StoreExportResponse) -> Self
fn from_wire(wire: StoreExportResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for StoreExportResponse
impl IntoNatural for StoreExportResponse
Sourcetype Natural = StoreExportResponse
type Natural = StoreExportResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StoreExportResponse
impl Wire for StoreExportResponse
Sourcetype Narrowed<'de> = StoreExportResponse
type Narrowed<'de> = StoreExportResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.